Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5878)

Unified Diff: chrome/browser/extensions/api/webrtc_audio_private/webrtc_audio_private_api.h

Issue 66183002: Replace MessageLoopProxy with SingleThreadTaskRunner for the rest of media/. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/webrtc_audio_private/webrtc_audio_private_api.h
diff --git a/chrome/browser/extensions/api/webrtc_audio_private/webrtc_audio_private_api.h b/chrome/browser/extensions/api/webrtc_audio_private/webrtc_audio_private_api.h
index 3f530563af1935b967be6404bfb98be838f1dd29..20f487f570d2f41d20e59db2b2f23502447f800f 100644
--- a/chrome/browser/extensions/api/webrtc_audio_private/webrtc_audio_private_api.h
+++ b/chrome/browser/extensions/api/webrtc_audio_private/webrtc_audio_private_api.h
@@ -16,7 +16,7 @@
#include "url/gurl.h"
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
}
namespace extensions {
@@ -107,8 +107,8 @@ class WebrtcAudioPrivateSetActiveSinkFunction
void SwitchDone();
void DoneOnUIThread();
- // Message loop of the thread this class is constructed on.
- const scoped_refptr<base::MessageLoopProxy> message_loop_;
+ // Task runner of the thread this class is constructed on.
+ const scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
int tab_id_;
std::string sink_id_;

Powered by Google App Engine
This is Rietveld 408576698